summaryrefslogtreecommitdiff
path: root/ucb/source/ucp/webdav/webdavcontent.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'ucb/source/ucp/webdav/webdavcontent.cxx')
-rw-r--r--ucb/source/ucp/webdav/webdavcontent.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/ucb/source/ucp/webdav/webdavcontent.cxx b/ucb/source/ucp/webdav/webdavcontent.cxx
index 2bfac0399d12..7ea094bb9791 100644
--- a/ucb/source/ucp/webdav/webdavcontent.cxx
+++ b/ucb/source/ucp/webdav/webdavcontent.cxx
@@ -835,16 +835,16 @@ void SAL_CALL Content::removeProperty( const rtl::OUString& Name )
uno::Reference< ucb::XCommandEnvironment > xEnv;
#if 0
// @@@ REMOVEABLE z.Z. nicht richtig an der PropSetInfo gesetzt!!!
try
{
beans::Property aProp
= getPropertySetInfo( xEnv, sal_False /* don't cache data */ )
->getPropertyByName( Name );
- if ( !( aProp.Attributes & beans::PropertyAttribute::REMOVEABLE ) )
+ if ( !( aProp.Attributes & beans::PropertyAttribute::REMOVABLE ) )
{
- // Not removeable!
+ // Not removable!
throw beans::NotRemoveableException();
}
}
@@ -835,16 +835,16 @@ void SAL_CALL Content::removeProperty( const rtl::OUString& Name )
uno::Reference< ucb::XCommandEnvironment > xEnv;
#if 0
- // @@@ REMOVEABLE z.Z. nicht richtig an der PropSetInfo gesetzt!!!
+ // @@@ REMOVABLE z.Z. nicht richtig an der PropSetInfo gesetzt!!!
try
{